@@ -5,10 +5,10 @@ import numpy as np
 import pandas as pd
 import matplotlib.pyplot as plt
 import matplotlib.lines as lines
-from ..wrappers.java.SIGMA import WrapperSIGMA as ws
-from ..plotters import PlotterSIGMA as p
-from ..data import DataRoxieParser as pd
-from ..data.DataModel import DataModel
+from steam_sdk.wrappers.java.SIGMA import WrapperSIGMA as ws
+from steam_sdk.plotters import PlotterSIGMA as p
+from steam_sdk.data import DataRoxieParser as pd
+from steam_sdk.data.DataModel import DataModel
 
 
 class BuilderSIGMA:
